@@ -34,6 +34,7 @@ enum class CityFlags {
 
 
 class City : IsPartOfGameInfoSerialization {
+    @Suppress("JoinDeclarationAndAssignment")
     @Transient
     lateinit var civ: Civilization
 
@@ -86,7 +87,13 @@ class City : IsPartOfGameInfoSerialization {
     var hasSoldBuildingThisTurn = false
     var isPuppet = false
     var updateCitizens = false  // flag so that on startTurn() the Governor reassigns Citizens
-    var cityAIFocus: CityFocus = CityFocus.NoFocus
+
+    var cityAIFocus: String = CityFocus.NoFocus.name
+    fun getCityFocus() = CityFocus.values().firstOrNull { it.name == cityAIFocus } ?: CityFocus.NoFocus
+    fun setCityFocus(cityFocus: CityFocus){ cityAIFocus = cityFocus.name }
+
+
+
     var avoidGrowth: Boolean = false
     @Transient var currentGPPBonus: Int = 0  // temporary variable saved for rankSpecialist()
 
@@ -209,100 +216,68 @@ class City : IsPartOfGameInfoSerialization {
     fun containsBuildingUnique(uniqueType: UniqueType) =
         cityConstructions.builtBuildingUniqueMap.getUniques(uniqueType).any()
 
-    fun getGreatPersonPercentageBonus() = getGreatPersonPercentageBonusBreakdown().sumOf { it.second }
-
-    @Suppress("RemoveExplicitTypeArguments")  // Clearer readability
-    /** Collects percentage boni applying to all GPP. Each returned entry is a Pair naming the source and the integer percentage. */
-    private fun getGreatPersonPercentageBonusBreakdown() = sequence<Pair<String, Int>> {
+    fun getGreatPersonPercentageBonus(): Int{
+        var allGppPercentageBonus = 0
         for (unique in getMatchingUniques(UniqueType.GreatPersonPointPercentage)) {
             if (!matchesFilter(unique.params[1])) continue
-            yield((unique.sourceObjectName ?: "Bonus") to unique.params[0].toInt())
+            allGppPercentageBonus += unique.params[0].toInt()
         }
 
         // Sweden UP
         for (otherCiv in civ.getKnownCivs()) {
             if (!civ.getDiplomacyManager(otherCiv).hasFlag(DiplomacyFlags.DeclarationOfFriendship))
                 continue
-            val boostUniques = civ.getMatchingUniques(UniqueType.GreatPersonBoostWithFriendship) +
-                otherCiv.getMatchingUniques(UniqueType.GreatPersonBoostWithFriendship)
-            for (unique in boostUniques)
-                yield("Declaration of Friendship" to unique.params[0].toInt())
+
+            for (ourUnique in civ.getMatchingUniques(UniqueType.GreatPersonBoostWithFriendship))
+                allGppPercentageBonus += ourUnique.params[0].toInt()
+            for (theirUnique in otherCiv.getMatchingUniques(UniqueType.GreatPersonBoostWithFriendship))
+                allGppPercentageBonus += theirUnique.params[0].toInt()
         }
+        return allGppPercentageBonus
     }
 
-    data class GreatPersonPointsBreakdownEntry(val source: String, val isBonus: Boolean, val counter: Counter<String> = Counter())
-    fun getGreatPersonPointsBreakdown(): Sequence<GreatPersonPointsBreakdownEntry> {
-        // First part: Base GPP points, materialized since we'll need to scan them twice
-        val basePoints = mutableListOf<GreatPersonPointsBreakdownEntry>()
+    fun getGreatPersonPointsForNextTurn(): HashMap<String, Counter<String>> {
+        val sourceToGPP = HashMap<String, Counter<String>>()
 
-        // ... from Specialists
-        val specialists = GreatPersonPointsBreakdownEntry("Specialists", false)
+        val specialistsCounter = Counter<String>()
         for ((specialistName, amount) in population.getNewSpecialists())
             if (getRuleset().specialists.containsKey(specialistName)) { // To solve problems in total remake mods
                 val specialist = getRuleset().specialists[specialistName]!!
-                specialists.counter.add(specialist.greatPersonPoints.times(amount))
+                specialistsCounter.add(specialist.greatPersonPoints.times(amount))
             }
-        basePoints.add(specialists)
+        sourceToGPP["Specialists"] = specialistsCounter
 
-        // ... and from buildings, allowing multiples of the same name to be aggregated since builtBuildingObjects is a List
-        basePoints.addAll(
-            cityConstructions.getBuiltBuildings()
-                .groupBy({ it.name }, { it.greatPersonPoints })
-                .map { GreatPersonPointsBreakdownEntry(
-                    it.key,
-                    false,
-                    it.value.fold(null) { a: Counter<String>?, b -> if (a == null) b else a + b }!! // Just a sumOf<Counter>, !! because groupBy doesn't output empty lists
-                ) }
-        )
+        val buildingsCounter = Counter<String>()
+        for (building in cityConstructions.getBuiltBuildings())
+            buildingsCounter.add(building.greatPersonPoints)
+        sourceToGPP["Buildings"] = buildingsCounter
 
-        return sequence {
-            // Second part: passing the first part through first, but collecting all names with base points while doing so
-            val allGpp = mutableSetOf<String>()
-            for (element in basePoints) {
-                yield(element)
-                allGpp += element.counter.keys
-            }
-
-            // Now add boni: GreatPersonPointPercentage and GreatPersonBoostWithFriendship
-            for ((source, bonus) in getGreatPersonPercentageBonusBreakdown()) {
-                val bonusEntry = GreatPersonPointsBreakdownEntry(source, true)
-                for (gppName in allGpp)
-                    bonusEntry.counter[gppName] = bonus
-                yield(bonusEntry)
-            }
-
-            // And last, the GPP-type-specific GreatPersonEarnedFaster Unique
-            val stateForConditionals = StateForConditionals(civInfo = civ, city = this@City)
+        val stateForConditionals = StateForConditionals(civInfo = civ, city = this)
+        for ((_, gppCounter) in sourceToGPP) {
             for (unique in civ.getMatchingUniques(UniqueType.GreatPersonEarnedFaster, stateForConditionals)) {
-                val bonusEntry = GreatPersonPointsBreakdownEntry(unique.sourceObjectName ?: "Bonus", true)
-                bonusEntry.counter.add(unique.params[0], unique.params[1].toInt())
-                yield(bonusEntry)
+                val unitName = unique.params[0]
+                if (!gppCounter.containsKey(unitName)) continue
+                gppCounter.add(unitName, gppCounter[unitName] * unique.params[1].toInt() / 100)
             }
+
+            val allGppPercentageBonus = getGreatPersonPercentageBonus()
+
+            for (unitName in gppCounter.keys)
+                gppCounter.add(unitName, gppCounter[unitName] * allGppPercentageBonus / 100)
         }
+
+        return sourceToGPP
     }
 
-    fun getGreatPersonPoints() = Counter<String>().apply {
-        // Using fixed-point(n.3) math to avoid surprises by rounding while still leveraging the Counter class
-        // Also accumulating boni separately - to ensure they operate additively not multiplicatively
-        val boni = Counter<String>()
-        for ((_, isBonus, counter) in getGreatPersonPointsBreakdown()) {
-            if (!isBonus) {
-                add(counter * 1000)
-            } else {
-                boni.add(counter)
-            }
-        }
-        for (key in keys.filter { it in boni }) {
-            add(key, this[key] * boni[key] / 100)
-        }
-        // round fixed-point to integers
-        for (key in keys)
-            this[key] = (this[key] * 0.001).roundToInt()
-
+    fun getGreatPersonPoints(): Counter<String> {
+        val gppCounter = Counter<String>()
+        for (entry in getGreatPersonPointsForNextTurn().values)
+            gppCounter.add(entry)
         // Remove all "gpp" values that are not valid units
-        for (key in keys.toSet())
+        for (key in gppCounter.keys.toSet())
             if (key !in getRuleset().units)
-                remove(key)
+                gppCounter.remove(key)
+        return gppCounter
     }
 
     fun addStat(stat: Stat, amount: Int) {
