@@ -3,7 +3,6 @@ package com.unciv.logic.civilization.managers
 import com.unciv.UncivGame
 import com.unciv.logic.VictoryData
 import com.unciv.logic.automation.civilization.NextTurnAutomation
-import com.unciv.logic.city.City
 import com.unciv.logic.city.managers.CityTurnManager
 import com.unciv.logic.civilization.AlertType
 import com.unciv.logic.civilization.CivFlags
@@ -17,11 +16,12 @@ import com.unciv.logic.map.mapunit.UnitTurnManager
 import com.unciv.logic.map.tile.Tile
 import com.unciv.logic.trade.TradeEvaluation
 import com.unciv.models.ruleset.ModOptionsConstants
+import com.unciv.models.ruleset.unique.StateForConditionals
+import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unique.endTurn
 import com.unciv.models.stats.Stats
 import com.unciv.ui.components.MayaCalendar
-import com.unciv.ui.components.extensions.randomWeighted
 import com.unciv.ui.screens.worldscreen.status.NextTurnProgress
 import com.unciv.utils.Log
 import kotlin.math.max
@@ -61,7 +61,7 @@ class TurnManager(val civInfo: Civilization) {
         if (civInfo.cities.isNotEmpty()) { //if no city available, addGreatPerson will throw exception
             val greatPerson = civInfo.greatPeople.getNewGreatPerson()
             if (greatPerson != null && civInfo.gameInfo.ruleset.units.containsKey(greatPerson))
-                civInfo.units.addUnit(greatPerson, getRandomWeightedCity(greatPerson))
+                civInfo.units.addUnit(greatPerson)
             civInfo.religionManager.startTurn()
             if (civInfo.isLongCountActive())
                 MayaCalendar.startTurnForMaya(civInfo)
@@ -96,19 +96,6 @@ class TurnManager(val civInfo: Civilization) {
         updateWinningCiv()
     }
 
-    /** Determine which city gets a new Great Person
-     *
-     *  - Choose randomly but chance proportional to the given city's contribution to [greatPerson]
-     *  - returning null will leave the decision to addUnit which will choose an unweighted random one
-     */
-    private fun getRandomWeightedCity(greatPerson: String): City? {
-        val cities = civInfo.cities.asSequence()
-            .map { it to it.getGreatPersonPoints()[greatPerson] }
-            .filter { it.second > 0 }
-            .toList()
-        if (cities.isEmpty()) return null
-        return cities.map { it.first }.randomWeighted(cities.map { it.second.toFloat() })
-    }
 
     private fun startTurnFlags() {
         for (flag in civInfo.flagsCountdown.keys.toList()) {
@@ -242,6 +229,9 @@ class TurnManager(val civInfo: Civilization) {
     fun endTurn(progressBar: NextTurnProgress? = null) {
         NextTurnAutomation.automateCityBombardment(civInfo) // Bombard with all cities that haven't, maybe you missed one
 
+        for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponTurnEnd, StateForConditionals(civInfo)))
+            UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo)
+
         val notificationsLog = civInfo.notificationsLog
         val notificationsThisTurn = Civilization.NotificationsLog(civInfo.gameInfo.turns)
         notificationsThisTurn.notifications.addAll(civInfo.notifications)
