@@ -1,13 +1,12 @@
 package com.unciv.ui.screens.modmanager
 
 import com.badlogic.gdx.Gdx
-import com.badlogic.gdx.files.FileHandle
 import com.badlogic.gdx.graphics.Texture
 import com.badlogic.gdx.scenes.scene2d.ui.Image
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.unciv.models.metadata.BaseRuleset
 import com.unciv.models.ruleset.Ruleset
-import com.unciv.models.ruleset.unique.UniqueType
+import com.unciv.models.ruleset.validation.ModCompatibility
 import com.unciv.models.translations.tr
 import com.unciv.ui.components.extensions.UncivDateFormat.formatDate
 import com.unciv.ui.components.extensions.UncivDateFormat.parseDate
@@ -52,7 +51,7 @@ internal class ModInfoAndActionPane : Table() {
         val modName = mod.name
         val modOptions = mod.modOptions  // The ModOptions as enriched by us with GitHub metadata when originally downloaded
         isBuiltin = modOptions.modUrl.isEmpty() && BaseRuleset.values().any { it.fullName == modName }
-        enableVisualCheckBox = shouldShowVisualCheckbox(mod)
+        enableVisualCheckBox = ModCompatibility.isAudioVisualMod(mod)
         update(
             modName, modOptions.modUrl, modOptions.defaultBranch,
             modOptions.lastUpdated, modOptions.author, modOptions.modSize
@@ -170,26 +169,4 @@ internal class ModInfoAndActionPane : Table() {
             cell.size(texture.width * resizeRatio, texture.height * resizeRatio)
         }
     }
-
-    private fun shouldShowVisualCheckbox(mod: Ruleset): Boolean {
-        val folder = mod.folderLocation ?: return false  // Also catches isBuiltin
-
-        // Check declared Mod Compatibility
-        if (mod.modOptions.hasUnique(UniqueType.ModIsAudioVisualOnly)) return true
-        if (mod.modOptions.hasUnique(UniqueType.ModIsAudioVisual)) return true
-        if (mod.modOptions.hasUnique(UniqueType.ModIsNotAudioVisual)) return false
-
-        // The following is the "guessing" part: If there's media, show the PAV choice...
-        // Might be deprecated if declarative Mod compatibility succeeds
-        fun isSubFolderNotEmpty(modFolder: FileHandle, name: String): Boolean {
-            val file = modFolder.child(name)
-            if (!file.exists()) return false
-            if (!file.isDirectory) return false
-            return file.list().isNotEmpty()
-        }
-        if (isSubFolderNotEmpty(folder, "music")) return true
-        if (isSubFolderNotEmpty(folder, "sounds")) return true
-        if (isSubFolderNotEmpty(folder, "voices")) return true
-        return folder.list("atlas").isNotEmpty()
-    }
 }
