@@ -1,8 +1,10 @@
 package com.unciv.ui.screens.overviewscreen
 
 import com.badlogic.gdx.graphics.Color
+import com.badlogic.gdx.math.Vector2
 import com.badlogic.gdx.scenes.scene2d.Actor
 import com.badlogic.gdx.scenes.scene2d.Group
+import com.badlogic.gdx.scenes.scene2d.Stage
 import com.badlogic.gdx.scenes.scene2d.Touchable
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.scenes.scene2d.ui.TextButton
@@ -15,24 +17,29 @@ import com.unciv.logic.civilization.diplomacy.DiplomaticStatus
 import com.unciv.logic.civilization.diplomacy.RelationshipLevel
 import com.unciv.logic.map.HexMath
 import com.unciv.models.ruleset.Policy.PolicyBranchType
+import com.unciv.models.ruleset.nation.getContrastRatio
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
 import com.unciv.ui.components.extensions.addBorder
 import com.unciv.ui.components.extensions.addSeparator
 import com.unciv.ui.components.extensions.addSeparatorVertical
 import com.unciv.ui.components.extensions.center
+import com.unciv.ui.components.extensions.equalizeColumns
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
 import com.unciv.ui.components.fonts.Fonts
+import com.unciv.ui.components.input.onActivation
 import com.unciv.ui.components.input.onClick
 import com.unciv.ui.components.widgets.AutoScrollPane
 import com.unciv.ui.components.widgets.ColorMarkupLabel
+import com.unciv.ui.components.widgets.ShadowedLabel
 import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.popups.AnimatedMenuPopup
 import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.diplomacyscreen.DiplomacyScreen
 import kotlin.math.roundToInt
 
-class GlobalPoliticsOverviewTable (
+class GlobalPoliticsOverviewTable(
     viewingPlayer: Civilization,
     overviewScreen: EmpireOverviewScreen,
     persistedData: EmpireOverviewTabPersistableData? = null
@@ -66,17 +73,31 @@ class GlobalPoliticsOverviewTable (
 
 
     init {
+        top()
         if (persistableData.showDiagram) updateDiagram()
         else updatePoliticsTable()
     }
 
+    override fun getFixedContent() = fixedContent
+
+    //region Politics Table View
+
     private fun updatePoliticsTable() {
         persistableData.showDiagram = false
-        clear()
-        fixedContent.clear()
+        createGlobalPoliticsHeader()
+        createGlobalPoliticsTable()
+        equalizeColumns(fixedContent, this)
+    }
 
+    /** Clears fixedContent and adds the header cells.
+     *  Needs to stay matched to [createGlobalPoliticsTable].
+     *
+     *  9 Columns: 5 info, 4 separators. First gets an empty header for contend below = civ image
+     */
+    private fun createGlobalPoliticsHeader() = fixedContent.run {
         val diagramButton = "Show diagram".toTextButton().onClick(::updateDiagram)
 
+        clear()
         add()
         addSeparatorVertical(Color.GRAY)
         add("Civilization Info".toLabel())
@@ -86,16 +107,22 @@ class GlobalPoliticsOverviewTable (
         add("Wonders".toLabel())
         addSeparatorVertical(Color.GRAY)
         add(Table().apply {
-            add("Relations".toLabel()).row()
+            add("Relations".toLabel()).padTop(10f).row()
             add(diagramButton).pad(10f)
         })
-
-        createGlobalPoliticsTable()
+        addSeparator(Color.GRAY)
     }
 
+    /** Clears [EmpireOverviewTab]'s main Table and adds data columns/rows.
+     *  Needs to stay matched to [createGlobalPoliticsHeader].
+     */
     private fun createGlobalPoliticsTable() {
+        clear()
+
         for (civ in sequenceOf(viewingPlayer) + viewingPlayer.diplomacyFunctions.getKnownCivsSorted(includeCityStates = false)) {
-            addSeparator(Color.GRAY)
+            // We already have a separator under the fixed header, we only need them here between rows.
+            // This is also the replacement for calling row() explicitly
+            if (cells.size > 0) addSeparator(Color.GRAY)
 
             // civ image
             add(ImageGetter.getNationPortrait(civ.nation, 100f)).pad(20f)
@@ -225,7 +252,8 @@ class GlobalPoliticsOverviewTable (
         return politicsTable
     }
 
-    override fun getFixedContent() = fixedContent
+    //endregion
+    //region Diagram View ("Ball of Yarn")
 
     // Refresh content and determine landscape/portrait layout
     private fun updateDiagram() {
@@ -406,6 +434,16 @@ class GlobalPoliticsOverviewTable (
 
         init {
             setSize(freeSize, freeSize)
+
+            // An Image Actor does not respect alpha for its hit area, it's always square, but we want a clickable _circle_
+            // Radius to show legend should be no larger than freeSize / 2.25f - 15f (see below), let's make it a little smaller
+            val clickableArea = ClickableCircle(freeSize / 1.25f - 25f)
+            clickableArea.onActivation {
+                DiagramLegendPopup(stage, this)
+            }
+            clickableArea.center(this)
+            addActor(clickableArea)
+
             val civGroups = HashMap<String, Actor>()
             val civLines = HashMap<String, MutableSet<Actor>>()
             val civCount = undefeatedCivs.count()
@@ -426,7 +464,7 @@ class GlobalPoliticsOverviewTable (
                 addActor(civGroup)
             }
 
-            for (civ in undefeatedCivs)
+            for (civ in undefeatedCivs) {
                 for (diplomacy in civ.diplomacy.values) {
                     if (diplomacy.otherCiv() !in undefeatedCivs) continue
                     val civGroup = civGroups[civ.civName]!!
@@ -437,7 +475,8 @@ class GlobalPoliticsOverviewTable (
                         startY = civGroup.y + civGroup.height / 2,
                         endX = otherCivGroup.x + otherCivGroup.width / 2,
                         endY = otherCivGroup.y + otherCivGroup.height / 2,
-                        width = 2f)
+                        width = 2f
+                    )
 
                     statusLine.color = if (diplomacy.diplomaticStatus == DiplomaticStatus.War) Color.RED
                     else if (diplomacy.diplomaticStatus == DiplomaticStatus.DefensivePact
@@ -451,6 +490,64 @@ class GlobalPoliticsOverviewTable (
 
                     addActorAt(0, statusLine)
                 }
+            }
+
         }
     }
+
+    private class DiagramLegendPopup(stage: Stage, diagram: Actor) : AnimatedMenuPopup(stage, diagram.getCenterInStageCoordinates()) {
+        init {
+            touchable = Touchable.enabled
+            onActivation { close() }
+        }
+
+        companion object {
+            private fun Actor.getCenterInStageCoordinates(): Vector2 = localToStageCoordinates(Vector2(width / 2, height / 2))
+
+            const val lineWidth = 3f  // a little thicker than the actual diagram
+            const val lowContrastWidth = 4f
+            const val lineLength = 120f
+        }
+
+        override fun createContentTable(): Table {
+            val legend = Table()
+            legend.background = ImageGetter.getDrawable("OtherIcons/Politics-diagram-bg")
+            legend.add(ShadowedLabel("Diagram line colors", Constants.headingFontSize)).colspan(2).row()
+            //todo Rethink hardcoding together with the statusLine.color one in DiplomacyGroup
+            legend.addLegendRow("War", Color.RED)
+            for (level in RelationshipLevel.values()) {
+                val lineColor = if (level == RelationshipLevel.Ally) Color.CYAN else level.color
+                legend.addLegendRow(level.name, lineColor)
+            }
+            legend.addLegendRow(Constants.defensivePact, Color.CYAN)
+            return super.createContentTable()!!.apply {
+                add(legend).grow()
+            }
+        }
+
+        fun Table.addLegendRow(text: String, color: Color) {
+            // empiric hack to equalize the "visual impact" a little. Afraid is worst at contrast 1.4, Enemy has 9.8
+            val contrast = getContrastRatio(Color.DARK_GRAY, color).toFloat()
+            val width = lineWidth + (lowContrastWidth - lineWidth) / contrast.coerceAtLeast(1f)
+            val line = ImageGetter.getLine(0f, width / 2, lineLength, width / 2, width)
+            line.color = color
+            add(line).size(lineLength, width).padTop(5f)
+            add(ShadowedLabel(text)).padLeft(5f).padTop(10f).row()
+        }
+    }
+
+    /** An Image Actor does not respect alpha for its hit area, it's always square, but we want a clickable _circle_ */
+    private class ClickableCircle(size: Float) : Group() {
+        val center = Vector2(size / 2, size / 2)
+        val maxDst2 = size * size / 4 // squared radius
+        init {
+            touchable = Touchable.enabled
+            setSize(size, size)
+        }
+        override fun hit(x: Float, y: Float, touchable: Boolean): Actor? {
+            return if (center.dst2(x, y) < maxDst2) this else null
+        }
+    }
+
+    //endregion
 }
